pub struct EntropyContext {
pub user_data: *mut u8,
pub size: usize,
}Expand description
Context data for entropy callbacks
This structure can be used to pass additional context to entropy callbacks, such as user data or configuration.
Fields
user_data: *mut u8User-defined context data
size: usizeContext size in bytes
Implementations