has_custom_entropy_source

Function has_custom_entropy_source 

pub fn has_custom_entropy_source() -> bool
Check if a custom entropy source is currently registered

Returns

Returns true if a custom entropy source is registered, false otherwise.